<?php

namespace Wp618\Stats;

if ( !defined( 'ABSPATH' ) ) exit;

//
class Api{
    //
    private $app;

    //
    public function __construct(){
        $this->app = App::getInstance();

        add_action('rest_api_init', [$this, 'custom_rest_api']);
    }

    //
    public function custom_rest_api() {
        register_rest_route('vo/v1', '/stats', [
            'methods' => 'GET',
            'callback' => [$this, 'custom_rest_api_callback'],
            'permission_callback' => '__return_true',
        ]);
    }

    //
    public function custom_rest_api_callback(){
        $data = $this->app->request->get('data', 'trim');
        $json = json_decode($data, true);
        if(empty($json)){
            wp_send_json_error(['msg' => 'empty data']);
            exit;
        }

        $keys = [
            'lang' => 127,
            'ua' => 255,
            'url' => 255,
            'referer' => 255,
            'screen' => 127,
            'platform' => 127,
            'color' => 'int'
        ];

        $data = [
            'ip' => $_SERVER['REMOTE_ADDR'],
            'location' => '-',
            'user_id' => (int) get_current_user_id(),
        ];

        foreach ($keys as $field => $type){
            if($type === 'int'){
                $line = isset($json[$field]) ? intval($json[$field]) : 0;
            }else{
                $line = isset($json[$field]) ? strip_tags($json[$field]) : '';
                $line = mb_substr($line, 0, $type, 'utf-8');
            }

            $data[$field] = $line;
        }

        /**
        'lang': navigator.language,
        'ua': navigator.userAgent,
        'url': document.URL,
        'referer': document.referrer,
        'screen': window.screen.width + 'x' + window.screen.height,
        'platform': navigator.platform,
        'color': window.screen.colorDepth,
         */

        $this->log_id = $this->app->visitor_model->insert($data);

        $this->delete_more_data();

        wp_send_json_success(['msg' => 'ok']);
    }

    //
    private function delete_more_data(){
        $max = get_config_value('general.max_count');
        if(empty($max)){
            $max = 10000;
        }

        $row_max = $this->app->visitor_model->get_one([
            'order' => 'id desc',
        ]);

        if(empty($row_max)){
            return false;
        }

        for($i = 0; $i < 10; $i++){
            $row_min = $this->app->visitor_model->get_one([
                'order' => 'id asc',
            ]);

            if(empty($row_min)){
                return false;
            }

            if(($row_max['id'] - $row_min['id']) >= $max){
                $this->app->visitor_model->delete(['id' => $row_min['id']]);
            }else{
                break;
            }
        }

        return true;
    }

}