<?php

namespace Wp618\Stats;

if ( !defined( 'ABSPATH' ) ) exit;

//
class Action{
    private $app;
    private $start_time = 0;
    private $log_id = 0;

    //
    public function __construct(){
        $this->app = App::getInstance();

        add_action('wp_enqueue_scripts', [$this, 'stats_enqueue_scripts']);
    }

    //
    public function stats_enqueue_scripts() {
        wp_enqueue_script('vo-stats', get_style_js_uri('/assets/stats.js'), [], null, true);

        wp_localize_script('vo-stats', 'voStatsData', [
            'home' => trim(home_url(), '/'),
        ]);
    }

    //
    public function add_log(){
        return false;
        if(is_404()){
            $this->start_time = microtime(true);

            $ip = $_SERVER['REMOTE_ADDR'];
            $lang = isset($_SERVER['HTTP_ACCEPT_LANGUAGE']) ? strip_tags($_SERVER['HTTP_ACCEPT_LANGUAGE']) : '-';
            $ua = isset($_SERVER['HTTP_USER_AGENT']) ? strip_tags($_SERVER['HTTP_USER_AGENT']) : '-';
            $ua = mb_substr($ua, 0, 255, 'utf-8');
            $referer = isset($_SERVER['HTTP_REFERER']) ? strip_tags($_SERVER['HTTP_REFERER']) : '-';
            $referer = mb_substr($referer, 0, 255, 'utf-8');

            $this->log_id = $this->app->visitor_model->insert([
                'ip' => $ip,
                'http_code' => 0,
                'request_method' => strtolower($_SERVER['REQUEST_METHOD']),
                'lang' => $lang,
                'ua' => $ua,
                'url' => $_SERVER['REQUEST_URI'],
                'location' => '-',
                'page_type' => '-',
                'time_ms' => 0,
                'referer' => $referer,
                'user_id' => (int) get_current_user_id(),
            ]);

            $this->delete_more_data();
        }

    }

    //
    public function update_log(){
        if($this->log_id > 0){
            $data = [
                'http_code' => $this->get_http_code(),
                'time_ms' => intval((microtime(true) - $this->start_time) * 1000),
                'page_type' => $this->get_page_type(),
            ];

            $this->app->visitor_model->update($data, ['id' => $this->log_id]);
        }

    }

    //
    private function get_page_type(){
        if(is_admin()){
            return '后台';
        }
        if(is_home()){
            return '首页(H)';
        }
        if(is_front_page()){
            return '首页(F)';
        }
        if(is_single()){
            return '详情';
        }
        if(is_page()){
            return '详情';
        }
        if(is_date()){
            return '日期';
        }
        if(is_author()){
            return '作者';
        }
        if(is_archive()){
            return '归档';
        }

        return '其他';
    }

    //
    private function get_http_code(){
        if(is_404()){
            return 404;
        }

        return 200;
    }

    //
    private function delete_more_data(){
        $max = get_config_value('general.max_count');
        if(empty($max)){
            $max = 10000;
        }

        $row_max = $this->app->visitor_model->get_one([
            'order' => 'id desc',
        ]);

        if(empty($row_max)){
            return false;
        }

        for($i = 0; $i < 10; $i++){
            $row_min = $this->app->visitor_model->get_one([
                'order' => 'id asc',
            ]);

            if(empty($row_min)){
                return false;
            }

            if(($row_max['id'] - $row_min['id']) >= $max){
                $this->app->visitor_model->delete(['id' => $row_min['id']]);
            }else{
                break;
            }
        }

        return true;
    }

}
